#ifndef doc_tab_class_H
#define doc_tab_class_H

#include <QTextEdit>
#include <QtWidgets>
#include "text_lighter.h"



class doc_tab_class : public QPlainTextEdit
{
Q_OBJECT

private:

QString _fDirectory;
QString _fName;
QString _fExtension;
bool _changed;
Lighter_class* _highlighter;

private:

public:

void linesHelp();

doc_tab_class(QWidget* p_parent = 0);

QString getFileDirectory() const
{return _fDirectory;}

QString getFileName() const
{return _fName;}

bool wasChanged() const
{return _changed;}

QString getFileExt() const
{return _fExtension;}

void setFileName(const QString& p_name)
{_fName = p_name;}

signals:

void changeWidTitle(const QString&, const QString&);
void fileChanded(const QString&);

public slots:

QString sltLoad();
QString sltLoad(const QString&);
void sltIsCodeDoc();
void sltSave();
void sltSaveAs(const QString&);
void sltLoadHighlight();
void sltDocChanged();
void sltSetChanged(bool);

void linePaintEvent(QPaintEvent *event);
int lineNumberAreaWidth();

protected:

void resizeEvent(QResizeEvent *event) override;

private slots:

void updateLineNumberAreaWidth(int newBlockCount);
void highlightCurrentLine();
void updateLineNumberArea(const QRect &rect, int dy);

private:
QWidget *lineNumberArea;
};

class LineNumberArea : public QWidget
{
public:
LineNumberArea(doc_tab_class *editor) : QWidget(editor), codeEditor(editor)
{}

QSize sizeHint() const override
{
  return QSize(codeEditor->lineNumberAreaWidth(), 0);
}

protected:
void paintEvent(QPaintEvent *event) override
{
  codeEditor->linePaintEvent(event);
}

private:
doc_tab_class *codeEditor;
};
#endif // doc_tab_class_H